package com.aidex.system.domain;

import com.aidex.common.annotation.Excel;
import com.aidex.common.core.domain.BaseEntity;
import com.aidex.common.utils.log.annotation.FieldRemark;
import com.aidex.common.utils.log.annotation.LogField;
import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import javax.validation.constraints.NotBlank;

/**
 * 船只管理对象 sys_ship
 * @author ChenSir
 * @email 91476835
 * @date 2024-03-16
 */
@Data
public class SysShip extends BaseEntity<SysShip>
{
    private static final long serialVersionUID = 1L;

    /** 船只编号 */
    @Excel(name = "船只编号")
    @NotBlank(message = "船只编号不允许为空")
    @LogField
    @FieldRemark(name = "船只编号",field = "shipNum")
    private String shipNum;

    /** 船只名称 */
    @Excel(name = "船只名称")
    @NotBlank(message = "船只名称不允许为空")
    @LogField
    @FieldRemark(name = "船只名称",field = "shipNanme")
    private String shipNanme;

    /** gps设备编号 */
    @Excel(name = "gps设备编号")
    @LogField
    @FieldRemark(name = "gps设备编号",field = "gpsDeviceNum")
    private String gpsDeviceNum;

    /** 核载人数 */
    @Excel(name = "核载人数")
    @LogField
    @FieldRemark(name = "核载人数",field = "nuclearLoadNum")
    private Long nuclearLoadNum;

    /** 当前维度 */
    @Excel(name = "当前维度")
    @LogField
    @FieldRemark(name = "当前维度",field = "lat")
    private String lat;

    /** 当前维度 */
    @Excel(name = "当前维度")
    @LogField
    @FieldRemark(name = "当前维度",field = "lng")
    private String lng;

    /** 船只在线状态（0 离线 1 在线） */
    @Excel(name = "船只在线状态", dictType = "sys_ship_status")
    @LogField
    @FieldRemark(name = "船只在线状态",field = "status")
    private String status;

    public void setShipNum(String shipNum)
    {
        this.shipNum = shipNum;
    }

    public String getShipNum()
    {
        return shipNum;
    }

    public void setShipNanme(String shipNanme)
    {
        this.shipNanme = shipNanme;
    }

    public String getShipNanme()
    {
        return shipNanme;
    }

    public void setGpsDeviceNum(String gpsDeviceNum)
    {
        this.gpsDeviceNum = gpsDeviceNum;
    }

    public String getGpsDeviceNum()
    {
        return gpsDeviceNum;
    }

    public void setNuclearLoadNum(Long nuclearLoadNum)
    {
        this.nuclearLoadNum = nuclearLoadNum;
    }

    public Long getNuclearLoadNum()
    {
        return nuclearLoadNum;
    }

    public void setLat(String lat)
    {
        this.lat = lat;
    }

    public String getLat()
    {
        return lat;
    }

    public void setLng(String lng)
    {
        this.lng = lng;
    }

    public String getLng()
    {
        return lng;
    }

    public void setStatus(String status)
    {
        this.status = status;
    }

    public String getStatus()
    {
        return status;
    }


    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("shipNum", getShipNum())
            .append("shipNanme", getShipNanme())
            .append("gpsDeviceNum", getGpsDeviceNum())
            .append("nuclearLoadNum", getNuclearLoadNum())
            .append("lat", getLat())
            .append("lng", getLng())
            .append("status", getStatus())
            .append("remark", getRemark())
            .append("id", getId())
            .append("createBy", getCreateBy())
            .append("createDept", getCreateDept())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .append("updateIp", getUpdateIp())
            .append("version", getVersion())
            .append("delFlag", getDelFlag())
            .toString();
    }
}
